# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class CloudspaceIdMetricBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'completed_at': 'datetime',
        'instance_type': 'str',
        'started_at': 'datetime',
        'step': 'str'
    }

    attribute_map = {
        'completed_at': 'completedAt',
        'instance_type': 'instanceType',
        'started_at': 'startedAt',
        'step': 'step'
    }

    def __init__(self, completed_at: 'datetime' =None, instance_type: 'str' =None, started_at: 'datetime' =None, step: 'str' =None):  # noqa: E501
        """CloudspaceIdMetricBody - a model defined in Swagger"""  # noqa: E501
        self._completed_at = None
        self._instance_type = None
        self._started_at = None
        self._step = None
        self.discriminator = None
        if completed_at is not None:
            self.completed_at = completed_at
        if instance_type is not None:
            self.instance_type = instance_type
        if started_at is not None:
            self.started_at = started_at
        if step is not None:
            self.step = step

    @property
    def completed_at(self) -> 'datetime':
        """Gets the completed_at of this CloudspaceIdMetricBody.  # noqa: E501


        :return: The completed_at of this CloudspaceIdMetricBody.  # noqa: E501
        :rtype: datetime
        """
        return self._completed_at

    @completed_at.setter
    def completed_at(self, completed_at: 'datetime'):
        """Sets the completed_at of this CloudspaceIdMetricBody.


        :param completed_at: The completed_at of this CloudspaceIdMetricBody.  # noqa: E501
        :type: datetime
        """

        self._completed_at = completed_at

    @property
    def instance_type(self) -> 'str':
        """Gets the instance_type of this CloudspaceIdMetricBody.  # noqa: E501


        :return: The instance_type of this CloudspaceIdMetricBody.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type: 'str'):
        """Sets the instance_type of this CloudspaceIdMetricBody.


        :param instance_type: The instance_type of this CloudspaceIdMetricBody.  # noqa: E501
        :type: str
        """

        self._instance_type = instance_type

    @property
    def started_at(self) -> 'datetime':
        """Gets the started_at of this CloudspaceIdMetricBody.  # noqa: E501


        :return: The started_at of this CloudspaceIdMetricBody.  # noqa: E501
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at: 'datetime'):
        """Sets the started_at of this CloudspaceIdMetricBody.


        :param started_at: The started_at of this CloudspaceIdMetricBody.  # noqa: E501
        :type: datetime
        """

        self._started_at = started_at

    @property
    def step(self) -> 'str':
        """Gets the step of this CloudspaceIdMetricBody.  # noqa: E501


        :return: The step of this CloudspaceIdMetricBody.  # noqa: E501
        :rtype: str
        """
        return self._step

    @step.setter
    def step(self, step: 'str'):
        """Sets the step of this CloudspaceIdMetricBody.


        :param step: The step of this CloudspaceIdMetricBody.  # noqa: E501
        :type: str
        """

        self._step = step

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudspaceIdMetricBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'CloudspaceIdMetricBody') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudspaceIdMetricBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'CloudspaceIdMetricBody') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other
