# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class CloudspacesIdBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data_connection_mounts': 'list[V1DataConnectionMount]',
        'description': 'str',
        'display_name': 'str',
        'env': 'list[V1EnvVar]',
        'is_cloudspace_private': 'bool',
        'is_code_private': 'bool',
        'is_published': 'bool',
        'publish_with_compute_name': 'str',
        'tags': 'list[V1CloudSpaceTag]',
        'thumbnail': 'str',
        'thumbnail_file_type': 'str',
        'user_metadata': 'str'
    }

    attribute_map = {
        'data_connection_mounts': 'dataConnectionMounts',
        'description': 'description',
        'display_name': 'displayName',
        'env': 'env',
        'is_cloudspace_private': 'isCloudspacePrivate',
        'is_code_private': 'isCodePrivate',
        'is_published': 'isPublished',
        'publish_with_compute_name': 'publishWithComputeName',
        'tags': 'tags',
        'thumbnail': 'thumbnail',
        'thumbnail_file_type': 'thumbnailFileType',
        'user_metadata': 'userMetadata'
    }

    def __init__(self, data_connection_mounts: 'list[V1DataConnectionMount]' =None, description: 'str' =None, display_name: 'str' =None, env: 'list[V1EnvVar]' =None, is_cloudspace_private: 'bool' =None, is_code_private: 'bool' =None, is_published: 'bool' =None, publish_with_compute_name: 'str' =None, tags: 'list[V1CloudSpaceTag]' =None, thumbnail: 'str' =None, thumbnail_file_type: 'str' =None, user_metadata: 'str' =None):  # noqa: E501
        """CloudspacesIdBody - a model defined in Swagger"""  # noqa: E501
        self._data_connection_mounts = None
        self._description = None
        self._display_name = None
        self._env = None
        self._is_cloudspace_private = None
        self._is_code_private = None
        self._is_published = None
        self._publish_with_compute_name = None
        self._tags = None
        self._thumbnail = None
        self._thumbnail_file_type = None
        self._user_metadata = None
        self.discriminator = None
        if data_connection_mounts is not None:
            self.data_connection_mounts = data_connection_mounts
        if description is not None:
            self.description = description
        if display_name is not None:
            self.display_name = display_name
        if env is not None:
            self.env = env
        if is_cloudspace_private is not None:
            self.is_cloudspace_private = is_cloudspace_private
        if is_code_private is not None:
            self.is_code_private = is_code_private
        if is_published is not None:
            self.is_published = is_published
        if publish_with_compute_name is not None:
            self.publish_with_compute_name = publish_with_compute_name
        if tags is not None:
            self.tags = tags
        if thumbnail is not None:
            self.thumbnail = thumbnail
        if thumbnail_file_type is not None:
            self.thumbnail_file_type = thumbnail_file_type
        if user_metadata is not None:
            self.user_metadata = user_metadata

    @property
    def data_connection_mounts(self) -> 'list[V1DataConnectionMount]':
        """Gets the data_connection_mounts of this CloudspacesIdBody.  # noqa: E501


        :return: The data_connection_mounts of this CloudspacesIdBody.  # noqa: E501
        :rtype: list[V1DataConnectionMount]
        """
        return self._data_connection_mounts

    @data_connection_mounts.setter
    def data_connection_mounts(self, data_connection_mounts: 'list[V1DataConnectionMount]'):
        """Sets the data_connection_mounts of this CloudspacesIdBody.


        :param data_connection_mounts: The data_connection_mounts of this CloudspacesIdBody.  # noqa: E501
        :type: list[V1DataConnectionMount]
        """

        self._data_connection_mounts = data_connection_mounts

    @property
    def description(self) -> 'str':
        """Gets the description of this CloudspacesIdBody.  # noqa: E501


        :return: The description of this CloudspacesIdBody.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description: 'str'):
        """Sets the description of this CloudspacesIdBody.


        :param description: The description of this CloudspacesIdBody.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_name(self) -> 'str':
        """Gets the display_name of this CloudspacesIdBody.  # noqa: E501


        :return: The display_name of this CloudspacesIdBody.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name: 'str'):
        """Sets the display_name of this CloudspacesIdBody.


        :param display_name: The display_name of this CloudspacesIdBody.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def env(self) -> 'list[V1EnvVar]':
        """Gets the env of this CloudspacesIdBody.  # noqa: E501


        :return: The env of this CloudspacesIdBody.  # noqa: E501
        :rtype: list[V1EnvVar]
        """
        return self._env

    @env.setter
    def env(self, env: 'list[V1EnvVar]'):
        """Sets the env of this CloudspacesIdBody.


        :param env: The env of this CloudspacesIdBody.  # noqa: E501
        :type: list[V1EnvVar]
        """

        self._env = env

    @property
    def is_cloudspace_private(self) -> 'bool':
        """Gets the is_cloudspace_private of this CloudspacesIdBody.  # noqa: E501


        :return: The is_cloudspace_private of this CloudspacesIdBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_cloudspace_private

    @is_cloudspace_private.setter
    def is_cloudspace_private(self, is_cloudspace_private: 'bool'):
        """Sets the is_cloudspace_private of this CloudspacesIdBody.


        :param is_cloudspace_private: The is_cloudspace_private of this CloudspacesIdBody.  # noqa: E501
        :type: bool
        """

        self._is_cloudspace_private = is_cloudspace_private

    @property
    def is_code_private(self) -> 'bool':
        """Gets the is_code_private of this CloudspacesIdBody.  # noqa: E501


        :return: The is_code_private of this CloudspacesIdBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_code_private

    @is_code_private.setter
    def is_code_private(self, is_code_private: 'bool'):
        """Sets the is_code_private of this CloudspacesIdBody.


        :param is_code_private: The is_code_private of this CloudspacesIdBody.  # noqa: E501
        :type: bool
        """

        self._is_code_private = is_code_private

    @property
    def is_published(self) -> 'bool':
        """Gets the is_published of this CloudspacesIdBody.  # noqa: E501


        :return: The is_published of this CloudspacesIdBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_published

    @is_published.setter
    def is_published(self, is_published: 'bool'):
        """Sets the is_published of this CloudspacesIdBody.


        :param is_published: The is_published of this CloudspacesIdBody.  # noqa: E501
        :type: bool
        """

        self._is_published = is_published

    @property
    def publish_with_compute_name(self) -> 'str':
        """Gets the publish_with_compute_name of this CloudspacesIdBody.  # noqa: E501


        :return: The publish_with_compute_name of this CloudspacesIdBody.  # noqa: E501
        :rtype: str
        """
        return self._publish_with_compute_name

    @publish_with_compute_name.setter
    def publish_with_compute_name(self, publish_with_compute_name: 'str'):
        """Sets the publish_with_compute_name of this CloudspacesIdBody.


        :param publish_with_compute_name: The publish_with_compute_name of this CloudspacesIdBody.  # noqa: E501
        :type: str
        """

        self._publish_with_compute_name = publish_with_compute_name

    @property
    def tags(self) -> 'list[V1CloudSpaceTag]':
        """Gets the tags of this CloudspacesIdBody.  # noqa: E501


        :return: The tags of this CloudspacesIdBody.  # noqa: E501
        :rtype: list[V1CloudSpaceTag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags: 'list[V1CloudSpaceTag]'):
        """Sets the tags of this CloudspacesIdBody.


        :param tags: The tags of this CloudspacesIdBody.  # noqa: E501
        :type: list[V1CloudSpaceTag]
        """

        self._tags = tags

    @property
    def thumbnail(self) -> 'str':
        """Gets the thumbnail of this CloudspacesIdBody.  # noqa: E501


        :return: The thumbnail of this CloudspacesIdBody.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail: 'str'):
        """Sets the thumbnail of this CloudspacesIdBody.


        :param thumbnail: The thumbnail of this CloudspacesIdBody.  # noqa: E501
        :type: str
        """

        self._thumbnail = thumbnail

    @property
    def thumbnail_file_type(self) -> 'str':
        """Gets the thumbnail_file_type of this CloudspacesIdBody.  # noqa: E501


        :return: The thumbnail_file_type of this CloudspacesIdBody.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_file_type

    @thumbnail_file_type.setter
    def thumbnail_file_type(self, thumbnail_file_type: 'str'):
        """Sets the thumbnail_file_type of this CloudspacesIdBody.


        :param thumbnail_file_type: The thumbnail_file_type of this CloudspacesIdBody.  # noqa: E501
        :type: str
        """

        self._thumbnail_file_type = thumbnail_file_type

    @property
    def user_metadata(self) -> 'str':
        """Gets the user_metadata of this CloudspacesIdBody.  # noqa: E501


        :return: The user_metadata of this CloudspacesIdBody.  # noqa: E501
        :rtype: str
        """
        return self._user_metadata

    @user_metadata.setter
    def user_metadata(self, user_metadata: 'str'):
        """Sets the user_metadata of this CloudspacesIdBody.


        :param user_metadata: The user_metadata of this CloudspacesIdBody.  # noqa: E501
        :type: str
        """

        self._user_metadata = user_metadata

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudspacesIdBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'CloudspacesIdBody') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudspacesIdBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'CloudspacesIdBody') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other
