# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1GetProjectBalanceResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'balance': 'float',
        'project_id': 'str',
        'top_ups': 'list[V1TopUp]',
        'transfers': 'list[V1Transfer]'
    }

    attribute_map = {
        'account_id': 'accountId',
        'balance': 'balance',
        'project_id': 'projectId',
        'top_ups': 'topUps',
        'transfers': 'transfers'
    }

    def __init__(self, account_id: 'str' =None, balance: 'float' =None, project_id: 'str' =None, top_ups: 'list[V1TopUp]' =None, transfers: 'list[V1Transfer]' =None):  # noqa: E501
        """V1GetProjectBalanceResponse - a model defined in Swagger"""  # noqa: E501
        self._account_id = None
        self._balance = None
        self._project_id = None
        self._top_ups = None
        self._transfers = None
        self.discriminator = None
        if account_id is not None:
            self.account_id = account_id
        if balance is not None:
            self.balance = balance
        if project_id is not None:
            self.project_id = project_id
        if top_ups is not None:
            self.top_ups = top_ups
        if transfers is not None:
            self.transfers = transfers

    @property
    def account_id(self) -> 'str':
        """Gets the account_id of this V1GetProjectBalanceResponse.  # noqa: E501


        :return: The account_id of this V1GetProjectBalanceResponse.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id: 'str'):
        """Sets the account_id of this V1GetProjectBalanceResponse.


        :param account_id: The account_id of this V1GetProjectBalanceResponse.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def balance(self) -> 'float':
        """Gets the balance of this V1GetProjectBalanceResponse.  # noqa: E501


        :return: The balance of this V1GetProjectBalanceResponse.  # noqa: E501
        :rtype: float
        """
        return self._balance

    @balance.setter
    def balance(self, balance: 'float'):
        """Sets the balance of this V1GetProjectBalanceResponse.


        :param balance: The balance of this V1GetProjectBalanceResponse.  # noqa: E501
        :type: float
        """

        self._balance = balance

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1GetProjectBalanceResponse.  # noqa: E501


        :return: The project_id of this V1GetProjectBalanceResponse.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1GetProjectBalanceResponse.


        :param project_id: The project_id of this V1GetProjectBalanceResponse.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def top_ups(self) -> 'list[V1TopUp]':
        """Gets the top_ups of this V1GetProjectBalanceResponse.  # noqa: E501


        :return: The top_ups of this V1GetProjectBalanceResponse.  # noqa: E501
        :rtype: list[V1TopUp]
        """
        return self._top_ups

    @top_ups.setter
    def top_ups(self, top_ups: 'list[V1TopUp]'):
        """Sets the top_ups of this V1GetProjectBalanceResponse.


        :param top_ups: The top_ups of this V1GetProjectBalanceResponse.  # noqa: E501
        :type: list[V1TopUp]
        """

        self._top_ups = top_ups

    @property
    def transfers(self) -> 'list[V1Transfer]':
        """Gets the transfers of this V1GetProjectBalanceResponse.  # noqa: E501


        :return: The transfers of this V1GetProjectBalanceResponse.  # noqa: E501
        :rtype: list[V1Transfer]
        """
        return self._transfers

    @transfers.setter
    def transfers(self, transfers: 'list[V1Transfer]'):
        """Sets the transfers of this V1GetProjectBalanceResponse.


        :param transfers: The transfers of this V1GetProjectBalanceResponse.  # noqa: E501
        :type: list[V1Transfer]
        """

        self._transfers = transfers

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1GetProjectBalanceResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1GetProjectBalanceResponse') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1GetProjectBalanceResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1GetProjectBalanceResponse') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other
