# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1AWSClusterSecondaryRegionSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'az_names': 'list[str]',
        'ec2_cpu_ami': 'str',
        'ec2_cpu_ami_cloud_space': 'str',
        'ec2_gpu_ami': 'str',
        'ec2_gpu_ami_cloud_space': 'str',
        'region': 'str'
    }

    attribute_map = {
        'az_names': 'azNames',
        'ec2_cpu_ami': 'ec2CpuAmi',
        'ec2_cpu_ami_cloud_space': 'ec2CpuAmiCloudSpace',
        'ec2_gpu_ami': 'ec2GpuAmi',
        'ec2_gpu_ami_cloud_space': 'ec2GpuAmiCloudSpace',
        'region': 'region'
    }

    def __init__(self, az_names: 'list[str]' =None, ec2_cpu_ami: 'str' =None, ec2_cpu_ami_cloud_space: 'str' =None, ec2_gpu_ami: 'str' =None, ec2_gpu_ami_cloud_space: 'str' =None, region: 'str' =None):  # noqa: E501
        """V1AWSClusterSecondaryRegionSpec - a model defined in Swagger"""  # noqa: E501
        self._az_names = None
        self._ec2_cpu_ami = None
        self._ec2_cpu_ami_cloud_space = None
        self._ec2_gpu_ami = None
        self._ec2_gpu_ami_cloud_space = None
        self._region = None
        self.discriminator = None
        if az_names is not None:
            self.az_names = az_names
        if ec2_cpu_ami is not None:
            self.ec2_cpu_ami = ec2_cpu_ami
        if ec2_cpu_ami_cloud_space is not None:
            self.ec2_cpu_ami_cloud_space = ec2_cpu_ami_cloud_space
        if ec2_gpu_ami is not None:
            self.ec2_gpu_ami = ec2_gpu_ami
        if ec2_gpu_ami_cloud_space is not None:
            self.ec2_gpu_ami_cloud_space = ec2_gpu_ami_cloud_space
        if region is not None:
            self.region = region

    @property
    def az_names(self) -> 'list[str]':
        """Gets the az_names of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501


        :return: The az_names of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._az_names

    @az_names.setter
    def az_names(self, az_names: 'list[str]'):
        """Sets the az_names of this V1AWSClusterSecondaryRegionSpec.


        :param az_names: The az_names of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :type: list[str]
        """

        self._az_names = az_names

    @property
    def ec2_cpu_ami(self) -> 'str':
        """Gets the ec2_cpu_ami of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501


        :return: The ec2_cpu_ami of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :rtype: str
        """
        return self._ec2_cpu_ami

    @ec2_cpu_ami.setter
    def ec2_cpu_ami(self, ec2_cpu_ami: 'str'):
        """Sets the ec2_cpu_ami of this V1AWSClusterSecondaryRegionSpec.


        :param ec2_cpu_ami: The ec2_cpu_ami of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :type: str
        """

        self._ec2_cpu_ami = ec2_cpu_ami

    @property
    def ec2_cpu_ami_cloud_space(self) -> 'str':
        """Gets the ec2_cpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501


        :return: The ec2_cpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :rtype: str
        """
        return self._ec2_cpu_ami_cloud_space

    @ec2_cpu_ami_cloud_space.setter
    def ec2_cpu_ami_cloud_space(self, ec2_cpu_ami_cloud_space: 'str'):
        """Sets the ec2_cpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.


        :param ec2_cpu_ami_cloud_space: The ec2_cpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :type: str
        """

        self._ec2_cpu_ami_cloud_space = ec2_cpu_ami_cloud_space

    @property
    def ec2_gpu_ami(self) -> 'str':
        """Gets the ec2_gpu_ami of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501


        :return: The ec2_gpu_ami of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :rtype: str
        """
        return self._ec2_gpu_ami

    @ec2_gpu_ami.setter
    def ec2_gpu_ami(self, ec2_gpu_ami: 'str'):
        """Sets the ec2_gpu_ami of this V1AWSClusterSecondaryRegionSpec.


        :param ec2_gpu_ami: The ec2_gpu_ami of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :type: str
        """

        self._ec2_gpu_ami = ec2_gpu_ami

    @property
    def ec2_gpu_ami_cloud_space(self) -> 'str':
        """Gets the ec2_gpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501


        :return: The ec2_gpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :rtype: str
        """
        return self._ec2_gpu_ami_cloud_space

    @ec2_gpu_ami_cloud_space.setter
    def ec2_gpu_ami_cloud_space(self, ec2_gpu_ami_cloud_space: 'str'):
        """Sets the ec2_gpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.


        :param ec2_gpu_ami_cloud_space: The ec2_gpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :type: str
        """

        self._ec2_gpu_ami_cloud_space = ec2_gpu_ami_cloud_space

    @property
    def region(self) -> 'str':
        """Gets the region of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501


        :return: The region of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region: 'str'):
        """Sets the region of this V1AWSClusterSecondaryRegionSpec.


        :param region: The region of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :type: str
        """

        self._region = region

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1AWSClusterSecondaryRegionSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1AWSClusterSecondaryRegionSpec') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1AWSClusterSecondaryRegionSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1AWSClusterSecondaryRegionSpec') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other
